<?php
namespace FM\Controller;

use FM\Controller\FMCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use FM\Service\MinhasTarefasService;
use FM\Traits\TResponse;

class MinhasTarefasController extends FMCrud {

    use TResponse;
    protected $dataSourceName = 'fcm_checklistagend';
    protected $MinhasTarefasService;

    public function __construct($crudService, $environment, $MinhasTarefasService) {
        parent::__construct($crudService, $environment);
        $this->MinhasTarefasService = $MinhasTarefasService;
    }
    
    // -------> FUNÇÕES DA TELA LISTA DE TAREFAS <-------- //

    public function getTarefasListadas(Request $request, Response $response) {
        try {
                $data = $this->MinhasTarefasService->getTarefasListadas($request->getParameters());
                $this->sendResponse($data, 200);
            } catch (Exception $ex) {
                $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
            }
    }

    public function getFotosTarefas(Request $request, Response $response) {
        try {
                $data = $this->MinhasTarefasService->getFotosTarefas($request->getParameters());
                $this->sendResponse($data, 200);
            } catch (Exception $ex) {
                $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
            }
    }

    public function excluirFotoTarefas(Request $request, Response $response) {
        try {
                $data = $this->MinhasTarefasService->excluirFotoTarefas($request->getParameters());
                $this->sendResponse($data, 200);
            } catch (Exception $ex) {
                $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
            }
    }

    // Funções da Tela Minhas Tarefas
    public function nextTaskCard(DTO\Request $request, DTO\Response $response) {
        try {
            $variavel = $this->MinhasTarefasService->nextTaskCard();
            $dtsVal = new DataSet('nextTC', $variavel);
            $response->addDataSet($dtsVal);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function changeStatusTask(DTO\Request $request, DTO\Response $response) {

        $parametro = $request->getParameters();

        $this->MinhasTarefasService->changeStatusTask($parametro);

    }

    // Funções da Tela de Detalhamento
    public function getDetailsTask(DTO\Request $request, DTO\Response $response) {

        $parametro = $request->getParameters();

        $variavel = $this->MinhasTarefasService->getDetailsTask($parametro);
        $dtsVal = new DataSet('cardDetails', $variavel);
        $response->addDataSet($dtsVal);
    }

    public function getItensDetailsTask(DTO\Request $request, DTO\Response $response) {

        $parametro = $request->getParameters();

        $variavel = $this->MinhasTarefasService->getItensDetailsTask($parametro);
        $dtsVal = new DataSet('cardItensDetails', $variavel);
        $response->addDataSet($dtsVal);
    }

    public function statusCheck(DTO\Request $request, DTO\Response $response) {
        $variavel = $this->MinhasTarefasService->statusCheck();
        $dtsVal = new DataSet('statuschk', $variavel);
        $response->addDataSet($dtsVal);
    }
    
    public function getitensDetailsTaskForVistoria(DTO\Request $request, DTO\Response $response) {
        $response->addDataSet(new DataSet('details', $this->MinhasTarefasService->itensDetailsTaskForVistoria($request->getParameters())));
    }

    public function finishTaskDetails(DTO\Request $request, DTO\Response $response) {

        $parametro = $request->getParameters();

        $variavel = $this->MinhasTarefasService->finishTaskDetails($parametro);
        $dtsVal = new DataSet('finishTask', [$variavel]);
        $response->addDataSet($dtsVal);
    }

    public function getDetailsTaskVistoria(DTO\Request $request, DTO\Response $response) {
        $response->addDataSet(new DataSet('details', $this->MinhasTarefasService->itensDetailsTaskForVistoria($request->getParameters())));
    }
}
?>