<?php
namespace FM\Service;

use FM\Factory\ListagemVistoriasFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DataSource\DataSet;
use FM\Service\FuncionariosHierarqService;
use FM\Service\FindService;


class ListagemVistoriasService {

    protected $connection;
    protected $ListagemVistoriasFactory;
    protected $FuncionariosHierarqService;
    protected $FindService;
    protected $Environment;
    protected $newCode;

    public function __construct (EntityManager $entityManager, ListagemVistoriasFactory $ListagemVistoriasFactory, FuncionariosHierarqService $FuncionariosHierarqService, FindService $FindService, Environment $Environment, NewCode $newCode) {
        $this->connection                   = $entityManager->getConnection();
        $this->ListagemVistoriasFactory     = $ListagemVistoriasFactory;
        $this->FuncionariosHierarqService   = $FuncionariosHierarqService;
        $this->FindService                  = $FindService;
        $this->Environment                  = $Environment;
        $this->newCode                      = $newCode;
    }

    public function getVistoriasListadas($parametros) {
        $filtro = '';
        $cdOperador = $this->Environment->getCdOperador(); 
        $retorno = $this->FuncionariosHierarqService->montarHierarquiaOperadores($cdOperador);

        
        if ($parametros['TIPO'] == "2") {

            if ($parametros['NRGERENCIAMENTOCHK'] != '' && $parametros['NRGERENCIAMENTOCHK'] != null) {
                $filtro = $filtro." AND GCHK.NRGERENCIAMENTOCHK = ".$parametros['NRGERENCIAMENTOCHK'];
            }
        } elseif($parametros['TIPO'] == "3") {
            if (isset($parametros['NRSEQCONTRATO'])) {
                $contratos = $this->FindService->formatarArray($parametros['NRSEQCONTRATO']);
                $filtro = $filtro." AND GCHK.NRSEQCONTRATO IN ( ".$contratos.")";
            }

            if (isset($parametros['CDCLIENTE'])) {
                $clientes = $this->FindService->formatarArray($parametros['CDCLIENTE']);
                $filtro = $filtro." AND LC.CDCLIENTE IN ( ".$clientes.")";
            }
        
            if (isset($parametros['NRLOCALCLIENTE'])) {
                $local = $this->FindService->formatarArray($parametros['NRLOCALCLIENTE']);
                $filtro = $filtro." AND GCHK.NRLOCALCLIENTE IN ( ".$local.")";
            }

            if (isset($parametros['CDOPERADOR'])) {
                $operadores = $this->FindService->formatarArray($parametros['CDOPERADOR']);
                $filtro = $filtro." AND GCHK.CDOPERADOR IN ( ".$operadores.")";
            }

            if (isset($parametros['IDSITUACAOGERCHK'])) {
                $situacao = $this->FindService->formatarArray($parametros['IDSITUACAOGERCHK']);
                $filtro = $filtro." AND GCHK.IDSITUACAOGERCHK IN ( ".$situacao.")";
            }
            
            if (isset($parametros['DTHORAGEND'])) {
                $dataInicial = $parametros['DTHORAGEND'][0];
                $dataFinal = array_key_exists("1", $parametros['DTHORAGEND']) ? $parametros['DTHORAGEND'][1] : null;

                if ($dataFinal != null) {
                    $filtro = $filtro." AND GCHK.DTHORAAGEND BETWEEN '".$dataInicial."' AND '".$dataFinal."'";
                } else {
                    $data = $dataInicial;
                    $filtro = $filtro." AND GCHK.DTHORAAGEND BETWEEN '".$data."' AND TO_DATE('".$data."')+30";
                }
            }
        } 

        return $this->ListagemVistoriasFactory->getVistoriasListadas($retorno, $filtro);
    }

    public function getFotosVistorias($parametros) {
        return $this->ListagemVistoriasFactory->getFotosVistorias(array(
            "NRGERENCIAMENTOCHK"    => $parametros['NRGERENCIAMENTOCHK'],
        ));
    }

    public function excluirFotoVistorias($parametros) {
        return $this->ListagemVistoriasFactory->excluirFotoVistorias(array(
            "NRFOTOTAREFAGERCHK"    => $parametros['NRFOTOTAREFAGERCHK'],
        ));
    }

    public function getCardsSurveys($parametro, $parametroIds) {
        $param = '';
        $filterPlace = 'N';
        $filterEmployee = 'N';
        $filterSituation = 'N';

        if ($parametro['selectPlace'] != '' && $parametro['selectPlace'] != null) {
            $param = $param." WHERE LC.NRLOCALCLIENTE = ".$parametro['selectPlace'];
            $filterPlace = 'S';
        }
        if ($parametro['selectEmplyoee'] != '' && $parametro['selectEmplyoee'] != null) {
            if( $filterPlace == 'N') {
                $param = $param." WHERE FUNC.CDOPERADOR = ".$parametro['selectEmplyoee'];
             } else {
                $param = $param." AND FUNC.CDOPERADOR = ".$parametro['selectEmplyoee'];
             }
            $filterEmployee = 'S';
        }
        if ($parametro['selectSituation'] != '' && $parametro['selectSituation'] != null) {
            if( $filterPlace == 'N' && $filterEmployee == 'N') {
                $param = $param." WHERE GCHK.IDSITUACAOGERCHK = ".$parametro['selectSituation'];
             } else {
                $param = $param." AND GCHK.IDSITUACAOGERCHK = ".$parametro['selectSituation'];
             }
            $filterSituation = 'S';
        }
        if ($parametro['TO_CHAR(GCHK.DTHORAAGEND,\'DD/MM/YYYY\')'] != '' && $parametro['TO_CHAR(GCHK.DTHORAAGEND,\'DD/MM/YYYY\')'] != null && strlen($parametro['TO_CHAR(GCHK.DTHORAAGEND,\'DD/MM/YYYY\')']) == 21) {
            if($filterPlace == 'N' && $filterEmployee == 'N' && $filterSituation == 'N' ) {
                $param = $param." WHERE TO_CHAR(GCHK.DTHORAAGEND,'DD/MM/YYYY') = ".$parametro['TO_CHAR(GCHK.DTHORAAGEND,\'DD/MM/YYYY\')'];
            } else {
                $param = $param." AND TO_CHAR(GCHK.DTHORAAGEND,'DD/MM/YYYY') = ".$parametro['TO_CHAR(GCHK.DTHORAAGEND,\'DD/MM/YYYY\')'];
            }
        }

        $usersIds = implode(',',$parametroIds); // Transforma o array em uma string com os ids

        $survey = $this->ListagemVistoriasFactory->cardsSurveys($param, $usersIds);
        return $survey;
    }

    public function getDetailsSurvey($params) {
        return $this->ListagemVistoriasFactory->getActivities(array(
            "NRGERENCIAMENTOCHK"    => $params['nr'],
        ));
    }

    // Funções da tela de Detalhes da Vistoria

    public function getTask($params) {

        $parametros = array(
            "NRATIVIDADECHK"        => $params['NRATIVIDADECHK'],
            "NRGERENCIAMENTOCHK"    => $params['NRGERENCIAMENTOCHK'],
        );

        $tasks = $this->ListagemVistoriasFactory->getTask($parametros);
        $paramReturn = array(
            "IDSITUACAOGERCHK" => $tasks[0]['IDSITUACAOGERCHK'],
            "IDSITUACAOAGEND"  => $tasks[0]['IDSITUACAOAGEND'],
            "DSOBSERVACAO"     => [],
            "IDOBRIGAOBSERVACAO" => $tasks[0]['IDOBRIGAOBSERVACAO'],
            "CRITERIOS"        => [],
            "CRITERIOSATIVOS"  => [],
        );

        foreach ($tasks as $task) {
            $criterias       = $this->ListagemVistoriasFactory->getCriteria(array(
                "NRTAREFAGERCHK" => $task["NRTAREFAGERCHK"]
                ));
                if (!in_array($task["DSOBSTAREFAGERCHK"], $paramReturn["DSOBSERVACAO"])) {
                    $paramReturn["DSOBSERVACAO"][] =  $task["DSOBSTAREFAGERCHK"];
                }
            foreach($criterias as $criteria) {
                if (!in_array($criteria["NMCRITERIOTARGERCHK"], $paramReturn["CRITERIOS"])) {
                    $paramReturn["CRITERIOS"][] =  $criteria["NMCRITERIOTARGERCHK"];
                }
                if ($criteria["IDMARCADO"] == "S" && !in_array($criteria["NMCRITERIOTARGERCHK"], $paramReturn["CRITERIOSATIVOS"])) {
                     $paramReturn["CRITERIOSATIVOS"][] =  $criteria["NMCRITERIOTARGERCHK"];
                }
            }
        }

       $paramReturn["DSOBSERVACAO"] = implode(',', $paramReturn["DSOBSERVACAO"]);

        return $paramReturn;
    }

     public function upSurveyCriterias($id, $params) {

        $this->connection->beginTransaction();
        // debugApi([$params]);

        try {
            foreach($params as $param) {
                if (!empty($param['valuesChkbox'])){
                    $parametros = array(
                        "NRATIVIDADECHK"     => $param['NRATIVIDADECHK'],
                        "NRGERENCIAMENTOCHK" => $param['NRGERENCIAMENTOCHK'],
                        "IDMARCADO"          => "N"
                    );

                    $this->ListagemVistoriasFactory->upCriterias($parametros, "");

                    $parametros["IDMARCADO"] = "S";
                    $paramQuery = " AND NMCRITERIOTARGERCHK IN(".$param['valuesChkbox'].")";

                    $this->ListagemVistoriasFactory->upCriterias($parametros, $paramQuery);

                    $parametros1 = array(
                        "NRATIVIDADECHK"     => $param['NRATIVIDADECHK'],
                        "NRGERENCIAMENTOCHK" => $param['NRGERENCIAMENTOCHK'],
                        "DSOBSTAREFAGERCHK"  => $param['valueObservation']
                    );

                    $this->ListagemVistoriasFactory->upObservation($parametros1);

                    $parametros2 = array(
                        "IDSITUACAOGERCHK"   => $id,
                        "NRGERENCIAMENTOCHK" => $param['NRGERENCIAMENTOCHK'],
                    );

                    $this->ListagemVistoriasFactory->upStatusSurvey($parametros2);

                } else {

                    if (empty($param['valuesChkbox'])){
                    $parametros = array(
                        "NRATIVIDADECHK"     => $param['NRATIVIDADECHK'],
                        "NRGERENCIAMENTOCHK" => $param['NRGERENCIAMENTOCHK'],
                        "IDMARCADO"          => "N"
                    );

                    $this->ListagemVistoriasFactory->upCriterias($parametros, "");

                    }

                    if (empty($param['valueObservation'])){
                        $textoPadrao = "Vistoria realizada, sem não-conformidades";
                        $parametros1 = array(
                            "NRATIVIDADECHK"     => $param['NRATIVIDADECHK'],
                            "NRGERENCIAMENTOCHK" => $param['NRGERENCIAMENTOCHK'],
                            "DSOBSTAREFAGERCHK"  => $textoPadrao
                        );


                        $this->ListagemVistoriasFactory->upObservation($parametros1);

                        $parametros2 = array(
                            "IDSITUACAOGERCHK"   => $id,
                            "NRGERENCIAMENTOCHK" => $param['NRGERENCIAMENTOCHK'],
                        );

                        $this->ListagemVistoriasFactory->upStatusSurvey($parametros2);

                    } else {
                        $parametros1 = array(
                            "NRATIVIDADECHK"     => $param['NRATIVIDADECHK'],
                            "NRGERENCIAMENTOCHK" => $param['NRGERENCIAMENTOCHK'],
                            "DSOBSTAREFAGERCHK"  => $param['valueObservation']
                        );

                        $this->ListagemVistoriasFactory->upObservation($parametros1);

                        $parametros2 = array(
                            "IDSITUACAOGERCHK"   => $id,
                            "NRGERENCIAMENTOCHK" => $param['NRGERENCIAMENTOCHK'],
                        );

                        $this->ListagemVistoriasFactory->upStatusSurvey($parametros2);
                    }

                }
            }
            $this->connection->commit();

        }  catch(\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
}