<?php
namespace FM\Service;

use FM\Factory\MinhasTarefasFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DataSource\DataSet;
use FM\Service\FuncionariosHierarqService;
use FM\Service\FindService;

class MinhasTarefasService {

    protected $MinhasTarefasFactory;
    protected $FuncionariosHierarqService;
    protected $FindService;
    protected $Environment;
    protected $newCode;

    public function __construct (EntityManager $entityManager, MinhasTarefasFactory $MinhasTarefasFactory, FuncionariosHierarqService $FuncionariosHierarqService, FindService $FindService, Environment $Environment, NewCode $newCode) {
        $this->connection                   = $entityManager->getConnection();
        $this->MinhasTarefasFactory         = $MinhasTarefasFactory;
        $this->FuncionariosHierarqService   = $FuncionariosHierarqService;
        $this->FindService                  = $FindService;
        $this->Environment                  = $Environment;
        $this->newCode                      = $newCode;
    }

    public function getFotosTarefas($parametros) {
        return $this->MinhasTarefasFactory->getFotosTarefas(array(
            "NRCHECKLISTAGEND" => $parametros['NRCHECKLISTAGEND']
        ));
    }

    public function excluirFotoTarefas($parametros) {
        return $this->MinhasTarefasFactory->excluirFotoTarefas(array(
            "NRFOTOTAREFAAGEND" => $parametros['NRFOTOTAREFAAGEND']
        ));
    }


    public function getTarefasListadas($parametros) {
        $filtro = '';
        $cdOperador = $this->Environment->getCdOperador(); 
        $retorno = $this->FuncionariosHierarqService->montarHierarquiaOperadores($cdOperador);

        
        if ($parametros['TIPO'] == "2") {

            if ($parametros['NRCHECKLISTAGEND'] != '' && $parametros['NRCHECKLISTAGEND'] != null) {
                $filtro = $filtro." AND CA.NRCHECKLISTAGEND = ".$parametros['NRCHECKLISTAGEND'];
            }
        } elseif($parametros['TIPO'] == "3") {

            if (isset($parametros['NRSEQCONTRATO'])) {
                $contratos = $this->FindService->formatarArray($parametros['NRSEQCONTRATO']);
                $filtro = $filtro." AND CA.NRSEQCONTRATO IN ( ".$contratos.")";
            }

            if (isset($parametros['CDCLIENTE'])) {
                $clientes = $this->FindService->formatarArray($parametros['CDCLIENTE']);
                $filtro = $filtro." AND LC.CDCLIENTE IN ( ".$clientes.")";
            }
        
            if (isset($parametros['NRLOCALCLIENTE'])) {
                $local = $this->FindService->formatarArray($parametros['NRLOCALCLIENTE']);
                $filtro = $filtro." AND CA.NRLOCALCLIENTE IN ( ".$local.")";
            }

            if (isset($parametros['CDOPERADOR'])) {
                $operadores = $this->FindService->formatarArray($parametros['CDOPERADOR']);
                $filtro = $filtro." AND CA.CDOPERADOR IN ( ".$operadores.")";
            }

            if (isset($parametros['IDSITUACAOAGEND'])) {
                $situacao = $this->FindService->formatarArray($parametros['IDSITUACAOAGEND']);
                $filtro = $filtro." AND CA.IDSITUACAOAGEND IN ( ".$situacao.")";
            }
            
            if (isset($parametros['DTHORAGEND'])) {
                $dataInicial = $parametros['DTHORAGEND'][0];
                $dataFinal = array_key_exists("1", $parametros['DTHORAGEND']) ? $parametros['DTHORAGEND'][1] : null;

                if ($dataFinal != null) {
                    $filtro = $filtro." AND CA.DTHORAAGEND BETWEEN '".$dataInicial."' AND '".$dataFinal."'";
                } else {
                    $data = $dataInicial;
                    $filtro = $filtro." AND CA.DTHORAAGEND BETWEEN '".$data."' AND TO_DATE('".$data."')+30";
                }
            }
        } 

        return $this->MinhasTarefasFactory->getTarefasListadas($retorno, $filtro);
    }


    // Funções da Tela Minhas Tarefas
    public function nextTaskCard() {
        
        return $this->MinhasTarefasFactory->nextTaskCard(array(
            "CDOPERADOR" => $this->Environment->getCdOperador()
        ));
    }

    public function changeStatusTask($params) {

        $parametros = array(
            "IDSITUACAOAGEND"    => $params['button'],
            "DSJUSTCANCELAMENTO" => (isset($params["DSJUSTCANCELAMENTO"])) ? $params["DSJUSTCANCELAMENTO"] : null,
            "NRCHECKLISTAGEND"   => $params['NRTAREFAATIVA']
        );

        $this->MinhasTarefasFactory->upStatusTask($parametros);
        
        if ($params['button'] == 3) {
            
            $parametros = array(
                "IDSITUACAOGERCHK"   => 4,
                "NRCHECKLISTAGEND"   => $params['NRTAREFAATIVA']
            );
            $this->MinhasTarefasFactory->upStatusVistoryCanc($parametros);
        }

        if ($params['button'] == 4) {
            $this->MinhasTarefasFactory->upFinishTask($params['NRTAREFAATIVA']);
        }
    }

    // Funções da Tela de Detalhamento
    public function getDetailsTask($params) {

        $parametros = array(
            "NRCHECKLISTAGEND"    => $params['nr'],
        );

        $details = $this->MinhasTarefasFactory->cardDetailsTask($parametros);
        return $details;
    }

    public function getItensDetailsTask($params) {

        $parametros = array(
            "NRCHECKLISTAGEND"    => $params['nr'],
        );

        $details = $this->MinhasTarefasFactory->itensDetailsTask($parametros);
        return $details;
    }

    public function statusCheck() {
  
        $status = $this->MinhasTarefasFactory->statusCheck(array(
            "CDOPERADOR" => $this->Environment->getCdOperador()
        ));
        return $status;
    }

    public function finishTaskDetails($params) {
        
        try{
            $parametros = array(
                "IDSITUACAOAGEND"    => 4,
                "DSJUSTCANCELAMENTO" => NULL,
                "NRCHECKLISTAGEND"   => $params['NRTAREFAATIVA']
            );
    
            $changeST = $this->MinhasTarefasFactory->upStatusTask($parametros);
    
            forEach($params['CHKBOX'] as $checkbox) {
               $parametros = array (
                    "NRCHECKLISTAGEND"   => $params['NRTAREFAATIVA'],
                    "NRTAREFAAGEND" => $checkbox,
                    "DSOBSTAREFAAGEND" => $params['DSOBSTAREFAAGEND']
                 );
    
                $this->MinhasTarefasFactory->upFinishDetailsTaks($parametros);
            }
           
           $return = 'OK';  
        }
        catch(\Exception $e) {
             $return = utf8_decode($e->getErrorCode());
        }
        
        return $return;
    }
    
    public function itensDetailsTaskForVistoria($params) {
        $parametros = array(
            "NRGERENCIAMENTOCHK"    => $params['NR'],
        );
        return $this->MinhasTarefasFactory->itensDetailsTaskForVistoria($parametros);
    }

}
?>
